 #!/bin/bash

set -e

dirname="$(dirname $0)"
cfgFile=$dirname/setup.cfg
nginxConfigDir=$dirname/ngnix

while getopts u:p:d:s: option
do
 case "${option}"
 in
 u) db_root_name=${OPTARG};;
 p) db_root_password=${OPTARG};;
 d) domain=${OPTARG};;
 s) skip=$OPTARG;;
 esac
done

if [ -f $cfgFile ]; then
    source $dirname/setup.cfg
fi

echo "                                          "
echo "┌┬┐┌─┐┌┬┐┌─┐╔═╗┌─┐┌─┐  ┌─┐┌─┐┌┬┐┬ ┬┌─┐";
echo "│││├┤  │ ├─┤╚═╗├┤ │    └─┐├┤  │ │ │├─┘";
echo "┴ ┴└─┘ ┴ ┴ ┴╚═╝└─┘└─┘  └─┘└─┘ ┴ └─┘┴  ";

if [ -z $skip ];then

    echo "Welcome to the metaSec james setup. This setup will help you to install James!"
    echo "Attention! This setup will drop (if excists) and create the james database. Type 'yes' to continue"

    read cont

    if ! [ "$cont" == "yes" ]; then
        echo "setup aborted"
        exit;
    fi
fi

if [ -z $db_root_name ];then
    echo -n "Please enter your database admin name: "
    read db_root_name
fi

if [ -z $db_root_password ];then
    echo -n "Please enter your database admin password: "
    read -s -p db_root_password
fi

until mysql -u $db_root_name -p$db_root_password  -e ";" ; do
        read -p "Please enter mysql user: " db_root_name
        read -s -p "Please enter mysql password: " db_root_password
done

if [ -z $domain ];then
    echo -n "Please enter your james full domainname ( testname.example.com ): "
    read domain
fi

if [ -f "/opt/metasec_james/$domain" ]; then
    echo "Domain already excists"
        exit 1;
fi

db_password=$(cat /dev/urandom | tr -dc 'a-zA-Z0-9' | fold -w  16 | head -n 1)
db_user=$(echo "$domain" | cut -d. -f1)
db_name=$db_user

james_user_name="james-adm@$domain"
james_user_password=$(cat /dev/urandom | tr -dc 'a-zA-Z0-9' | fold -w 16 | head -n 1)
james_user_password=$(echo -n $james_user_password | md5sum | awk '{print $1}')
#james_user_password="098f6bcd4621d373cade4e832627b4f6"

mysql -u $db_root_name -p$db_root_password -e "DROP DATABASE IF EXISTS $db_name;"
mysql -u $db_root_name -p$db_root_password -e "GRANT USAGE ON *.* TO '$db_user'@'localhost'"
mysql -u $db_root_name -p$db_root_password -e "DROP USER '$db_user'@'localhost';"

mysql -u $db_root_name -p$db_root_password -e "CREATE USER '$db_user'@'localhost' IDENTIFIED BY '$db_password';"
mysql -u $db_root_name -p$db_root_password -e "CREATE DATABASE $db_name"
mysql -u $db_root_name -p$db_root_password -e "GRANT ALL ON $db_name.* to '$db_user'@'localhost';"

mysql -u $db_user -p$db_password $db_name < /usr/share/metasec_core/sampledata/sql/james-structure.sql
mysql -u$db_user -p$db_password $db_name -e "INSERT INTO persons
            (pe_login_ok, pe_name, pe_vorname, pe_email, pe_passwd, pe_tz, pe_acl, pe_view_mode, pe_deleted) VALUES
            (1,'James','Admin','$james_user_name','$james_user_password','Europe/Berlin','A,AC,ACL,GD','G',0);"

mkdir -p /opt/metasec_james/$domain

mkdir -p /opt/metasec_james/$domain/docs
mkdir -p /opt/metasec_james/$domain/metadata
mkdir -p /opt/metasec_james/$domain/templates
mkdir -p /opt/metasec_james/$domain/media
mkdir -p /opt/metasec_james/$domain/wf_rules

chown -R www-data:www-data /opt/metasec_james
chown -R www-data:www-data /opt/metasec_james_tpl
chown -R www-data:www-data /opt/metasec_james/$domain

touch /opt/metasec_james/$domain/config.inc.php

echo "<?php " 													>> /opt/metasec_james/$domain/config.inc.php 
echo "\$CCBOX[\"SQL\"][\"DB\"]   = \"$db_name\";"				>> /opt/metasec_james/$domain/config.inc.php 
echo "\$CCBOX[\"SQL\"][\"USER\"] = \"$db_user\";" 				>> /opt/metasec_james/$domain/config.inc.php
echo "\$CCBOX[\"SQL\"][\"PASS\"] = \"$db_password\";"			>> /opt/metasec_james/$domain/config.inc.php
echo " ?>" 														>> /opt/metasec_james/$domain/config.inc.php 

echo "+++++++++++++++++"
echo "Login:"
echo "E-Mail: james-adm@$domain" 
echo "Password: $james_user_password"
echo "+++++++++++++++++"

echo "Setup finished. Please restart the nginx service (service nginx restart)"

exit 0
